@@ -152,9 +152,14 @@ Creando un archivo temporal.</translation>
     <message>
         <source>More info: http://mnemosyne-proj.sourceforge.net
 </source>
-        <translation>Más información: http://mnemosyne-proj.sourceforge.net
+        <translation type="obsolete">Más información: http://mnemosyne-proj.sourceforge.net
 </translation>
     </message>
+    <message>
+        <source>More info: http://mnemosyne-proj.org
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AboutFrm</name>
@@ -382,7 +387,7 @@ Creando un archivo temporal.</translation>
     </message>
     <message>
         <source>&amp;Preview</source>
-        <translation>&amp;Previsualizar</translation>
+        <translation type="obsolete">&amp;Previsualizar</translation>
     </message>
     <message>
         <source>Ctrl+P</source>
@@ -396,6 +401,10 @@ Creando un archivo temporal.</translation>
         <source>Alt+X</source>
         <translation>Alt+S</translation>
     </message>
+    <message>
+        <source>Preview</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChangeCategoryFrm</name>
@@ -514,6 +523,10 @@ Creando un archivo temporal.</translation>
         <source>&amp;Cancel</source>
         <translation>&amp;Cancelar</translation>
     </message>
+    <message>
+        <source>Learn new cards in random order</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -694,6 +707,10 @@ Tal vez desee ejecutar </translation>
         <source>&amp;Find</source>
         <translation>&amp;Buscar</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="obsolete"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemsFrm</name>
@@ -729,6 +746,10 @@ Tal vez desee ejecutar </translation>
         <source>Alt+X</source>
         <translation>Alt+S</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ExportDlg</name>
@@ -898,7 +919,7 @@ Tal vez desee ejecutar </translation>
     </message>
     <message>
         <source>Show &amp;answer</source>
-        <translation>Mostrar &amp;respuesta</translation>
+        <translation type="obsolete">Mostrar &amp;respuesta</translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
@@ -932,6 +953,10 @@ Tal vez desee ejecutar </translation>
         <source> days.</source>
         <translation type="unfinished"> días.</translation>
     </message>
+    <message>
+        <source>Show answer</source>
+        <translation type="unfinished">Mostrar respuesta</translation>
+    </message>
 </context>
 <context>
     <name>MainFrm</name>
@@ -1444,6 +1469,34 @@ Puede obtener más información en http://www.mnemosyne-proj.sourceforge.net.
         <source>Grade</source>
         <translation>Puntuación</translation>
     </message>
+    <message>
+        <source>No current card.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Grade:</source>
+        <translation type="unfinished">Puntuación:</translation>
+    </message>
+    <message>
+        <source>Easiness:</source>
+        <translation type="unfinished">Facilidad:</translation>
+    </message>
+    <message>
+        <source>Repetitions:</source>
+        <translation type="unfinished">Repeticiones:</translation>
+    </message>
+    <message>
+        <source>Lapses:</source>
+        <translation type="unfinished">Olvidos:</translation>
+    </message>
+    <message>
+        <source>Days since last repetition:</source>
+        <translation type="unfinished">Días desde la última repetición:</translation>
+    </message>
+    <message>
+        <source>Days until next repetition:</source>
+        <translation type="unfinished">Días hasta la próxima repetición:</translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
@@ -1475,6 +1528,10 @@ Puede obtener más información en http://www.mnemosyne-proj.sourceforge.net.
         <source>&amp;OK</source>
         <translation>&amp;Aceptar</translation>
     </message>
+    <message>
+        <source>Current card</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TipDlg</name>
