@@ -20,6 +20,7 @@ from product_tour_dlg import *
 from tip_dlg import *
 from about_dlg import *
 from sound import *
+from card_prop import *
 from message_boxes import *
 from mnemosyne.core import *
 
@@ -85,7 +86,11 @@ class MainDlg(MainFrm):
         self.state = "EMPTY"
         self.item = None
         
-        self.shrink = True
+        if sys.platform == 'darwin':
+            # Solves bug that this doesn't become False on resize.
+            self.shrink = False
+        else:
+            self.shrink = True
 
         self.q_sound_played = False
         self.a_sound_played = False
@@ -99,6 +104,15 @@ class MainDlg(MainFrm):
         self.statusBar().addWidget(self.all,0,1)
         self.statusBar().setSizeGripEnabled(0)
 
+        if sys.platform == 'darwin':
+            
+            # The size grip cannot be disabled for OSX, this will 
+            # add extra spacing to prevent part of self.all getting
+            # obscured.
+            
+            osx_spacing = QLabel("   ", self.statusBar())
+            self.statusBar().addWidget(osx_spacing,0,1)
+
         self.grade_buttons = []
 
         self.grade_buttons.append(self.grade_0_button)
@@ -107,6 +121,11 @@ class MainDlg(MainFrm):
         self.grade_buttons.append(self.grade_3_button) 
         self.grade_buttons.append(self.grade_4_button)
         self.grade_buttons.append(self.grade_5_button)
+
+        try:
+            run_plugins()
+        except MnemosyneError, e:
+            messagebox_errors(self, e)
                 
         if filename == None:
             filename = get_config("path")
@@ -121,11 +140,6 @@ class MainDlg(MainFrm):
         self.newQuestion()
         self.updateDialog()
 
-        try:
-            run_plugins()
-        except MnemosyneError, e:
-            messagebox_errors(self, e)
-
         self.timer = QTimer(self)
         self.connect(self.timer, SIGNAL("timeout()"), soundmanager.update)
         self.timer.start(250, False)
@@ -151,8 +165,7 @@ class MainDlg(MainFrm):
 
         pause_thinking()
 
-        path = os.path.join(os.path.expanduser("~"), ".mnemosyne")
-        out = unicode(QFileDialog.getSaveFileName(path,
+        out = unicode(QFileDialog.getSaveFileName(basedir,
                  self.trUtf8("Mnemosyne databases (*.mem)"), self, None,\
                  self.trUtf8("New")))
         if out != "":
@@ -380,7 +393,7 @@ class MainDlg(MainFrm):
     def showStatistics(self):
         
         pause_thinking()
-        dlg = StatisticsDlg(self)
+        dlg = StatisticsDlg(self.item, self)
         dlg.exec_loop()
         unpause_thinking()
         
@@ -552,8 +565,10 @@ class MainDlg(MainFrm):
             self.item = get_new_question(learn_ahead)
             if self.item != None:
                 self.state = "SELECT SHOW"
+                self.style = card_props(self.item.filtered_q())
             else:
                 self.state = "SELECT AHEAD"
+                self.style = card_props("")
 
         self.q_sound_played = False
         self.a_sound_played = False
@@ -673,11 +688,31 @@ class MainDlg(MainFrm):
         self.question.setAlignment(alignment)
         self.answer.setAlignment(alignment)
 
+        # Hide/show the question and answer boxes
+        
+        if self.state == "SELECT SHOW":
+            self.question.show()
+            self.question_label.show()
+            if self.style["answerbox"] == "overlay":
+                self.answer.hide()
+                self.answer_label.hide()
+        elif self.state == "SELECT GRADE":
+            self.answer.show()
+            self.answer_label.show()
+            if self.style["answerbox"] == "overlay":
+                self.question.hide()
+                self.question_label.hide()
+        else:
+            self.question.show()
+            self.question_label.show()
+            self.answer.show()
+            self.answer_label.show()
+        
         # Update question label.
         
         question_label_text = self.trUtf8("Question:")
         if self.item!=None and self.item.cat.name!=self.trUtf8("<default>"):
-            question_label_text += " " + preprocess(self.item.cat.name)
+            question_label_text += " " + self.item.cat.name
         self.question_label.setText(question_label_text)
 
         # Update question content.
@@ -685,7 +720,7 @@ class MainDlg(MainFrm):
         if self.item == None:
             self.question.setText("")
         else:
-            text = preprocess(self.item.q)
+            text = self.item.filtered_q()
 
             if self.q_sound_played == False:
                 play_sound(text)
@@ -701,7 +736,7 @@ class MainDlg(MainFrm):
         if self.item == None or self.state == "SELECT SHOW":
             self.answer.setText("")
         else:
-            text = preprocess(self.item.a)
+            text = self.item.filtered_a()
 
             if self.a_sound_played == False:
                 play_sound(text)
@@ -714,13 +749,13 @@ class MainDlg(MainFrm):
         # Update 'show answer' button.
         
         if self.state == "EMPTY":
-            show_enabled, default, text = 0, 1, self.trUtf8("Show &answer")
+            show_enabled, default, text = 0, 1, self.trUtf8("Show answer")
             grades_enabled = 0
         elif self.state == "SELECT SHOW":
-            show_enabled, default, text = 1, 1, self.trUtf8("Show &answer")
+            show_enabled, default, text = 1, 1, self.trUtf8("Show answer")
             grades_enabled = 0
         elif self.state == "SELECT GRADE":
-            show_enabled, default, text = 0, 1, self.trUtf8("Show &answer")
+            show_enabled, default, text = 0, 1, self.trUtf8("Show answer")
             grades_enabled = 1
         elif self.state == "SELECT AHEAD":
             show_enabled, default, text = 1, 0, \
@@ -791,6 +826,6 @@ class MainDlg(MainFrm):
     ##########################################################################
 
     def replaySound(self):
-        play_sound(preprocess(self.item.q))
+        play_sound(self.item.filtered_q())
         if self.state == "SELECT GRADE":
-            play_sound(preprocess(self.item.a))
+            play_sound(self.item.filtered_a())
